﻿Imports IBackupCloud.Storage.FileSystem
Namespace Storage.AmazonS3

    Public Class Explorer
        Implements Storage.Base.IExplorer

        Private AccountImageIndex As Integer = 0
        Private AccountSelectedImageIndex As Integer = 0
        Private NodeImageIndex As Integer = 0
        Private NodeSelectedImageIndex As Integer = 0

        Public Sub FillDirectoryInTreeNode(ByVal directoryPath As String, ByRef treeNode As System.Windows.Forms.TreeNode) Implements Base.IExplorer.FillDirectoryInTreeNode
            Dim tempNode As TreeNode
            For Each _S3Directory As S3Directory In S3Directory.GetFileSystemEntries(directoryPath)
                tempNode = New TreeNode(_S3Directory.Name)
                If treeNode.Nodes.Contains(tempNode) = False Then
                    With treeNode.Nodes.Add(_S3Directory.Name)
                        .ImageIndex = NodeImageIndex
                        .SelectedImageIndex = NodeSelectedImageIndex
                        .Tag = _S3Directory.FullName
                    End With
                End If
            Next
        End Sub

        Public Sub FillDirectoryInTreeView(ByVal directoryPath As String, ByRef treeView As System.Windows.Forms.TreeView) Implements Base.IExplorer.FillDirectoryInTreeView
            For Each _S3Directory As S3Directory In S3Directory.GetFileSystemEntries(directoryPath)
                With treeView.Nodes.Add(_S3Directory.Name)
                    .ImageIndex = NodeImageIndex
                    .SelectedImageIndex = NodeSelectedImageIndex
                    .Tag = _S3Directory.FullName
                End With
            Next
        End Sub

        Public Sub FillFilesInListView(ByVal directoryPath As String, ByRef listView As System.Windows.Forms.ListView) Implements Base.IExplorer.FillFilesInListView
            listView.Items.Clear()
            Dim fileextension As String = ""
            Dim imglst As ImageList = listView.SmallImageList

            For Each _S3File As S3File In S3Directory.GetFiles(directoryPath)
                fileextension = _S3File.Extension
                If imglst.Images.ContainsKey(fileextension) = False Then
                    imglst.Images.Add(fileextension, FileIcon.getIconForExtension(fileextension))
                End If
                With listView.Items.Add(_S3File.Name)
                    .ImageKey = fileextension
                    .SubItems.Add(FileSize.GetSize(_S3File.Length))
                    .SubItems.Add(_S3File.CreationTime.ToShortDateString)
                    .SubItems.Add(_S3File.CreationTime.ToShortTimeString)
                    .SubItems.Add(_S3File.DirectoryName)
                    .Tag = _S3File.FullName
                End With
            Next
        End Sub

        Public Sub FillNodesInTreeView(ByRef treeView As System.Windows.Forms.TreeView) Implements Base.IExplorer.FillNodesInTreeView
            For Each account As AmazonS3.Account In AmazonS3.Account.GetAccounts()
                With treeView.Nodes.Add(account.Name)
                    .ImageIndex = AccountImageIndex
                    .SelectedImageIndex = AccountSelectedImageIndex
                    .Tag = account.Name
                End With
            Next
        End Sub

        Public Sub New(ByVal accountImageIndex As Integer, ByVal accountSelectedImageIndex As Integer, _
                        ByVal nodeImageIndex As Integer, ByVal nodeSelectedImageIndex As Integer)
            Me.AccountImageIndex = accountImageIndex
            Me.AccountSelectedImageIndex = accountSelectedImageIndex
            Me.NodeImageIndex = nodeImageIndex
            Me.NodeSelectedImageIndex = nodeSelectedImageIndex
        End Sub

        Public Sub FillFilesInTreeNode(ByVal directoryPath As String, ByRef treeNode As System.Windows.Forms.TreeNode) Implements Base.IExplorer.FillFilesInTreeNode
            Dim fileextension As String = ""
            Dim imglst As ImageList = treeNode.TreeView.ImageList

            For Each _S3File As S3File In S3Directory.GetFiles(directoryPath)
                fileextension = _S3File.Extension
                If imglst.Images.ContainsKey(fileextension) = False Then
                    imglst.Images.Add(fileextension, FileIcon.getIconForExtension(fileextension))
                End If
                If treeNode.Nodes.ContainsKey(_S3File.Name) = False Then
                    With treeNode.Nodes.Add(_S3File.Name, _S3File.Name)
                        .ImageKey = fileextension
                        .SelectedImageKey = fileextension
                        .Tag = _S3File.FullName
                    End With
                End If
            Next
        End Sub
    End Class

End Namespace