﻿Imports System.IO
Namespace Storage.FileSystem

    Public Class Explorer
        Implements Storage.Base.IExplorer

        Private DriveImageIndex As Integer = 0
        Private DriveSelectedImageIndex As Integer = 0
        Private NodeImageIndex As Integer = 0
        Private NodeSelectedImageIndex As Integer = 0

        Public Sub FillDirectoryInTreeNode(ByVal directoryPath As String, ByRef treeNode As System.Windows.Forms.TreeNode) Implements Base.IExplorer.FillDirectoryInTreeNode
            If Directory.Exists(directoryPath) = False Then
                Exit Sub
            End If

            Dim DirInfo As DirectoryInfo
            Dim strFileSystem() As String
            Dim strTemp As String
            Try
                strFileSystem = Directory.GetFileSystemEntries(directoryPath)
            Catch ex As Exception
                Exit Sub
            End Try
            For Each strTemp In strFileSystem
                If Directory.Exists(strTemp) = True Then
                    DirInfo = New DirectoryInfo(strTemp)
                    If treeNode.Nodes.ContainsKey(DirInfo.Name) = False Then
                        With treeNode.Nodes.Add(DirInfo.Name, DirInfo.Name)
                            .ImageIndex = NodeImageIndex
                            .SelectedImageIndex = NodeSelectedImageIndex
                            .Tag = DirInfo.FullName
                        End With
                    End If
                End If
            Next
        End Sub

        Public Sub FillDirectoryInTreeView(ByVal directoryPath As String, ByRef treeView As System.Windows.Forms.TreeView) Implements Base.IExplorer.FillDirectoryInTreeView
            If Directory.Exists(directoryPath) = False Then
                Exit Sub
            End If

            Dim DirInfo As DirectoryInfo
            Dim strFileSystem() As String
            Dim strTemp As String
            Try
                strFileSystem = Directory.GetFileSystemEntries(directoryPath)
            Catch ex As Exception
                Exit Sub
            End Try

            For Each strTemp In strFileSystem
                If Directory.Exists(strTemp) = True Then
                    DirInfo = New DirectoryInfo(strTemp)
                    If treeView.Nodes.ContainsKey(DirInfo.Name) = False Then
                        With treeView.Nodes.Add(DirInfo.Name, DirInfo.Name)
                            .ImageIndex = NodeImageIndex
                            .SelectedImageIndex = NodeSelectedImageIndex
                            .Tag = DirInfo.FullName
                        End With
                    End If
                End If
            Next
        End Sub

        Public Sub FillFilesInListView(ByVal directoryPath As String, ByRef listView As System.Windows.Forms.ListView) Implements Base.IExplorer.FillFilesInListView
            listView.Items.Clear()
            Dim objFileInfo As FileInfo
            Dim strFile() As String
            Try
                strFile = Directory.GetFiles(directoryPath)
            Catch ex As Exception
                Exit Sub
            End Try
            If strFile Is Nothing Then Exit Sub
            Dim fileextension As String = ""
            Dim imglst As ImageList = listView.SmallImageList

            If strFile.GetUpperBound(0) >= 0 Then
                For j As Integer = 0 To strFile.GetUpperBound(0)
                    objFileInfo = New FileInfo(strFile(j))
                    fileextension = objFileInfo.Extension
                    If imglst.Images.ContainsKey(fileextension) = False Then
                        imglst.Images.Add(fileextension, FileIcon.getIconForExtension(fileextension))
                    End If
                    With listView.Items.Add(objFileInfo.Name)
                        .ImageKey = fileextension
                        .SubItems.Add(FileSize.GetSize(objFileInfo.Length))
                        .SubItems.Add(objFileInfo.CreationTime.ToShortDateString)
                        .SubItems.Add(objFileInfo.CreationTime.ToShortTimeString)
                        .SubItems.Add(objFileInfo.DirectoryName)
                        .Tag = objFileInfo.FullName
                    End With
                Next
            End If
        End Sub

        Public Sub FillNodesInTreeView(ByRef treeView As System.Windows.Forms.TreeView) Implements Base.IExplorer.FillNodesInTreeView
            For Each driveInfo As System.IO.DriveInfo In System.IO.DriveInfo.GetDrives()
                With treeView.Nodes.Add(driveInfo.Name)
                    .ImageIndex = DriveImageIndex
                    .SelectedImageIndex = DriveSelectedImageIndex
                    .Tag = driveInfo.Name
                End With
            Next
        End Sub

        Public Sub New(ByVal driveImageIndex As Integer, ByVal driveSelectedImageIndex As Integer, _
                        ByVal nodeImageIndex As Integer, ByVal nodeSelectedImageIndex As Integer)
            Me.DriveImageIndex = driveImageIndex
            Me.DriveSelectedImageIndex = driveSelectedImageIndex
            Me.NodeImageIndex = nodeImageIndex
            Me.NodeSelectedImageIndex = nodeSelectedImageIndex
        End Sub

        Public Sub FillFilesInTreeNode(ByVal directoryPath As String, ByRef treeNode As System.Windows.Forms.TreeNode) Implements Base.IExplorer.FillFilesInTreeNode
            Dim objFileInfo As FileInfo
            Dim strFile() As String
            Try
                strFile = Directory.GetFiles(directoryPath)
            Catch ex As Exception
                Exit Sub
            End Try
            If strFile Is Nothing Then Exit Sub
            Dim fileextension As String = ""
            Dim imglst As ImageList = treeNode.TreeView.ImageList

            If strFile.GetUpperBound(0) >= 0 Then
                For j As Integer = 0 To strFile.GetUpperBound(0)
                    objFileInfo = New FileInfo(strFile(j))
                    fileextension = objFileInfo.Extension
                    If imglst.Images.ContainsKey(fileextension) = False Then
                        imglst.Images.Add(fileextension, FileIcon.getIconForExtension(fileextension))
                    End If
                    If treeNode.Nodes.ContainsKey(objFileInfo.Name) = False Then
                        With treeNode.Nodes.Add(objFileInfo.Name, objFileInfo.Name)
                            .ImageKey = fileextension
                            .SelectedImageKey = fileextension
                            .Tag = objFileInfo.FullName
                        End With
                    End If
                Next
            End If
        End Sub
    End Class

End Namespace